<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Axel Schwarzer <SchwarzerA@gmail.com>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Eric Haberstroh <ehaberstroh@gmail.com>
 * @author C!own77 <clown77@posteo.de>
 * @author Anonymous <anonymous@example.org>
 * @author Michaelsy <github@informantum.de>
 * @author Benjamin Molitor <bmolitor@uos.de>
 * @author Alex Beck <alex@4becks.com>
 * @author Jürgen Fredriksson <jfriedrich@gmx.at>
 * @author Sebastian Engel <mail@engel-s.de>
 * @author Karl_de_Hall <Karl.Grohmueller@sonnenhof-sha.de>
 * @author Michael Bohn <mjbohn@gmail.com>
 * @author Joel Strasser <strasser999@gmail.com>
 * @author Robert Riebisch <robert.riebisch@googlemail.com>
 * @author Joerg <scooter22@gmx.de>
 * @author Christof <gagi@fin.de>
 * @author Anika Henke <anika@selfthinker.org>
 * @author Esther Brunner <esther@kaffeehaus.ch>
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 * @author Dirk Einecke <dirk@dirkeinecke.de>
 * @author Blitzi94 <Blitzi94@gmx.de>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Niels Lange <niels@boldencursief.nl>
 * @author Christian Wichmann <nospam@zone0.de>
 * @author Matthias Schulte <mailinglist@lupo49.de>
 * @author Paul Lachewsky <kaeptn.haddock@gmail.com>
 * @author Pierre Corell <info@joomla-praxis.de>
 * @author Mateng Schimmerlos <mateng@firemail.de>
 * @author Benedikt Fey <spam@lifeisgoooood.de>
 * @author Simon <st103267@stud.uni-stuttgart.de>
 * @author Hoisl <hoisl@gmx.at>
 * @author Marcel Eickhoff <eickhoff.marcel@gmail.com>
 * @author Pascal Schröder <Pascal1802@gmail.com>
 * @author Hendrik Diel <diel.hendrik@gmail.com>
 * @author Marco Hofmann <xenadmin@meinekleinefarm.net>
 * @author Hella Breitkopf <hella.breitkopf@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Diese Seite bearbeiten';
$lang['btn_source']            = 'Zeige Quelltext';
$lang['btn_show']              = 'Seite anzeigen';
$lang['btn_create']            = 'Seite anlegen';
$lang['btn_search']            = 'Suche';
$lang['btn_save']              = 'Speichern';
$lang['btn_preview']           = 'Vorschau';
$lang['btn_top']               = 'Nach oben';
$lang['btn_newer']             = '<< neuere Änderungen';
$lang['btn_older']             = 'ältere Änderungen >>';
$lang['btn_revs']              = 'Ältere Versionen';
$lang['btn_recent']            = 'Letzte Änderungen';
$lang['btn_upload']            = 'Hochladen';
$lang['btn_cancel']            = 'Abbrechen';
$lang['btn_index']             = 'Übersicht';
$lang['btn_secedit']           = 'Bearbeiten';
$lang['btn_login']             = 'Anmelden';
$lang['btn_logout']            = 'Abmelden';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Aktualisieren';
$lang['btn_delete']            = 'Löschen';
$lang['btn_back']              = 'Zurück';
$lang['btn_backlink']          = 'Links hierher';
$lang['btn_subscribe']         = 'Aboverwaltung';
$lang['btn_profile']           = 'Benutzerprofil';
$lang['btn_reset']             = 'Zurücksetzen';
$lang['btn_resendpwd']         = 'Setze neues Passwort';
$lang['btn_draft']             = 'Entwurf bearbeiten';
$lang['btn_recover']           = 'Entwurf wiederherstellen';
$lang['btn_draftdel']          = 'Entwurf löschen';
$lang['btn_revert']            = 'Wiederherstellen';
$lang['btn_register']          = 'Registrieren';
$lang['btn_apply']             = 'Übernehmen';
$lang['btn_media']             = 'Medien-Manager';
$lang['btn_deleteuser']        = 'Benutzerprofil löschen';
$lang['btn_img_backto']        = 'Zurück zu %s';
$lang['btn_mediaManager']      = 'Im Medien-Manager anzeigen';
$lang['loggedinas']            = 'Angemeldet als:';
$lang['user']                  = 'Benutzername';
$lang['pass']                  = 'Passwort';
$lang['newpass']               = 'Neues Passwort';
$lang['oldpass']               = 'Bestätigen (Altes Passwort)';
$lang['passchk']               = 'Passwort erneut eingeben';
$lang['remember']              = 'Angemeldet bleiben';
$lang['fullname']              = 'Voller Name';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Benutzerprofil';
$lang['badlogin']              = 'Benutzername oder Passwort sind falsch.';
$lang['badpassconfirm']        = 'Das Passwort war falsch.';
$lang['minoredit']             = 'kleine Änderung';
$lang['draftdate']             = 'Entwurf gespeichert am';
$lang['nosecedit']             = 'Diese Seite wurde in der Zwischenzeit geändert, der Seitenabschnitt ist veraltet, lade stattdessen volle Seite.';
$lang['searchcreatepage']      = 'Falls der gesuchte Begriff nicht gefunden wurde, können Sie direkt eine neue, nach Ihrer Anfrage benannte Seite %s anlegen.';
$lang['search_fullresults']    = 'Volltextergebnisse';
$lang['js']['search_toggle_tools'] = 'Suchwerkzeuge umschalten';
$lang['js']['willexpire']      = 'Die Sperre zur Bearbeitung dieser Seite läuft in einer Minute ab.\nUm Bearbeitungskonflikte zu vermeiden, sollten Sie sie durch einen Klick auf den Vorschau-Knopf verlängern.';
$lang['js']['notsavedyet']     = 'Nicht gespeicherte Änderungen gehen verloren!';
$lang['js']['searchmedia']     = 'Suche Dateien';
$lang['js']['keepopen']        = 'Fenster nach Auswahl nicht schließen';
$lang['js']['hidedetails']     = 'Details ausblenden';
$lang['js']['mediatitle']      = 'Linkeinstellungen';
$lang['js']['mediadisplay']    = 'Linktyp';
$lang['js']['mediaalign']      = 'Ausrichtung';
$lang['js']['mediasize']       = 'Bildgröße';
$lang['js']['mediatarget']     = 'Linkziel';
$lang['js']['mediaclose']      = 'Schließen';
$lang['js']['mediainsert']     = 'Einfügen';
$lang['js']['mediadisplayimg'] = 'Bild anzeigen.';
$lang['js']['mediadisplaylnk'] = 'Nur den Link anzeigen.';
$lang['js']['mediasmall']      = 'Kleine Version';
$lang['js']['mediamedium']     = 'Mittlere Version';
$lang['js']['medialarge']      = 'Große Version';
$lang['js']['mediaoriginal']   = 'Originalversion';
$lang['js']['medialnk']        = 'Link zur Detailseite';
$lang['js']['mediadirect']     = 'Direktlink zum Original';
$lang['js']['medianolnk']      = 'Kein Link';
$lang['js']['medianolink']     = 'Bild nicht verlinken';
$lang['js']['medialeft']       = 'Das Bild links ausrichten.';
$lang['js']['mediaright']      = 'Das Bild rechts ausrichten.';
$lang['js']['mediacenter']     = 'Das Bild in der Mitte ausrichten.';
$lang['js']['medianoalign']    = 'Keine Ausrichtung benutzen.';
$lang['js']['nosmblinks']      = 'Das Verlinken von Windows-Freigaben funktioniert nur im Microsoft Internet Explorer.\nDer Link kann jedoch durch Kopieren und Einfügen verwendet werden.';
$lang['js']['linkwiz']         = 'Link-Assistent';
$lang['js']['linkto']          = 'Link nach:';
$lang['js']['del_confirm']     = 'Eintrag wirklich löschen?';
$lang['js']['restore_confirm'] = 'Wirklich diese Version wiederherstellen?';
$lang['js']['media_diff']      = 'Unterschiede anzeigen:';
$lang['js']['media_diff_both'] = 'Nebeneinander';
$lang['js']['media_diff_opacity'] = 'Überblenden';
$lang['js']['media_diff_portions'] = 'Übergang';
$lang['js']['media_select']    = 'Dateien auswählen…';
$lang['js']['media_upload_btn'] = 'Hochladen';
$lang['js']['media_done_btn']  = 'Fertig';
$lang['js']['media_drop']      = 'Dateien hier hinziehen, um sie hochzuladen';
$lang['js']['media_cancel']    = 'Entfernen';
$lang['js']['media_overwrt']   = 'Existierende Dateien überschreiben';
$lang['search_exact_match']    = 'Genaue Treffer';
$lang['search_starts_with']    = 'Beginnt mit';
$lang['search_ends_with']      = 'Endet mit';
$lang['search_contains']       = 'Enthält';
$lang['search_custom_match']   = 'Angepasst ';
$lang['search_any_ns']         = 'Alle Namensräume';
$lang['search_any_time']       = 'Jederzeit';
$lang['search_past_7_days']    = 'Letzte Woche';
$lang['search_past_month']     = 'Letzter Monat';
$lang['search_past_year']      = 'letztes Jahr';
$lang['search_sort_by_hits']   = 'Sortiere nach Treffer';
$lang['search_sort_by_mtime']  = 'Sortiere nach letzter Änderung';
$lang['regmissing']            = 'Bitte alle Felder ausfüllen!';
$lang['reguexists']            = 'Der Benutzername existiert leider schon.';
$lang['regsuccess']            = 'Der neue Benutzer wurde angelegt und das Passwort per E-Mail versandt.';
$lang['regsuccess2']           = 'Der neue Benutzer wurde angelegt.';
$lang['regfail']               = 'Der Benutzer konnte nicht angelegt werden.';
$lang['regmailfail']           = 'Offenbar ist ein Fehler beim Versenden der Passwort-E-Mail aufgetreten. Bitte wenden Sie sich an den Wiki-Admin.';
$lang['regbadmail']            = 'Die angegebene E-Mail-Adresse scheint ungültig zu sein. Falls dies ein Fehler ist, wenden Sie sich bitte an den Wiki-Admin.';
$lang['regbadpass']            = 'Die beiden eingegeben Passwörter stimmen nicht überein. Bitte versuchen Sie es noch einmal.';
$lang['regpwmail']             = 'Ihr DokuWiki-Passwort';
$lang['reghere']               = 'Sie haben noch keinen Zugang? Hier registrieren';
$lang['profna']                = 'Änderung des Benutzerprofils in diesem Wiki nicht möglich.';
$lang['profnochange']          = 'Keine Änderungen, nichts zu tun.';
$lang['profnoempty']           = 'Es muss ein Name und eine E-Mail-Adresse angegeben werden.';
$lang['profchanged']           = 'Benutzerprofil erfolgreich geändert.';
$lang['profnodelete']          = 'Dieses Wiki unterstützt kein Löschen von Benutzern.';
$lang['profdeleteuser']        = 'Benutzerprofil löschen';
$lang['profdeleted']           = 'Ihr Benutzerprofil wurde im Wiki gelöscht.';
$lang['profconfdelete']        = 'Ich möchte mein Benutzerprofil löschen.<br/> Diese Aktion lässt sich nicht rückgängig machen,';
$lang['profconfdeletemissing'] = 'Bestätigung in Kontrollkästchen fehlt';
$lang['proffail']              = 'Das Benutzerkonto konnte nicht aktualisiert werden.';
$lang['pwdforget']             = 'Passwort vergessen? Fordern Sie ein neues an';
$lang['resendna']              = 'Passwörter versenden ist in diesem Wiki nicht möglich.';
$lang['resendpwd']             = 'Neues Passwort setzen für';
$lang['resendpwdmissing']      = 'Es tut mir leid, aber Sie müssen alle Felder ausfüllen.';
$lang['resendpwdnouser']       = 'Es tut mir leid, aber der Benutzer existiert nicht in unserer Datenbank.';
$lang['resendpwdbadauth']      = 'Es tut mir leid, aber dieser Authentifizierungscode ist ungültig. Stellen Sie sicher, dass Sie den kompletten Bestätigungslink verwendet haben.';
$lang['resendpwdconfirm']      = 'Ein Bestätigungslink wurde per E-Mail versandt.';
$lang['resendpwdsuccess']      = 'Ihr neues Passwort wurde per E-Mail versandt.';
$lang['license']               = 'Falls nicht anders bezeichnet, ist der Inhalt dieses Wikis unter der folgenden Lizenz veröffentlicht:';
$lang['licenseok']             = 'Hinweis: Durch das Bearbeiten dieser Seite geben Sie Ihr Einverständnis, dass Ihr Inhalt unter der folgenden Lizenz veröffentlicht wird:';
$lang['searchmedia']           = 'Suche Dateinamen:';
$lang['searchmedia_in']        = 'Suche in %s';
$lang['txt_upload']            = 'Datei zum Hochladen auswählen:';
$lang['txt_filename']          = 'Hochladen als (optional):';
$lang['txt_overwrt']           = 'Bestehende Datei überschreiben';
$lang['maxuploadsize']         = 'Max. %s pro Datei-Upload.';
$lang['allowedmime']           = 'Liste der erlaubten Dateiendungen';
$lang['lockedby']              = 'Momentan gesperrt von:';
$lang['lockexpire']            = 'Sperre läuft ab am:';
$lang['rssfailed']             = 'Es ist ein Fehler beim Laden des Feeds aufgetreten: ';
$lang['nothingfound']          = 'Nichts gefunden.';
$lang['mediaselect']           = 'Dateiauswahl';
$lang['uploadsucc']            = 'Datei wurde erfolgreich hochgeladen';
$lang['uploadfail']            = 'Hochladen fehlgeschlagen. Keine Berechtigung?';
$lang['uploadwrong']           = 'Hochladen verweigert. Diese Dateiendung ist nicht erlaubt.';
$lang['uploadexist']           = 'Datei existiert bereits. Keine Änderungen vorgenommen.';
$lang['uploadbadcontent']      = 'Die hochgeladenen Daten stimmen nicht mit der Dateiendung %s überein.';
$lang['uploadspam']            = 'Hochladen verweigert: Treffer auf der Spamliste.';
$lang['uploadxss']             = 'Hochladen verweigert: Daten scheinen Schadcode zu enthalten.';
$lang['uploadsize']            = 'Die hochgeladene Datei war zu groß. (max. %s)';
$lang['deletesucc']            = 'Die Datei "%s" wurde gelöscht.';
$lang['deletefail']            = '"%s" konnte nicht gelöscht werden - prüfen Sie die Berechtigungen.';
$lang['mediainuse']            = 'Die Datei "%s" wurde nicht gelöscht - sie wird noch verwendet.';
$lang['namespaces']            = 'Namensräume';
$lang['mediafiles']            = 'Vorhandene Dateien in';
$lang['accessdenied']          = 'Diese Seite dürfen sie nicht sehen.';
$lang['mediausage']            = 'Syntax zum Verwenden dieser Datei:';
$lang['mediaview']             = 'Originaldatei öffnen';
$lang['mediaroot']             = 'Wurzel';
$lang['mediaupload']           = 'Laden Sie hier eine Datei in den momentanen Namensraum hoch. Um Unterordner zu erstellen, stellen Sie diese dem Dateinamen durch Doppelpunkt getrennt voran, nachdem Sie die Datei ausgewählt haben.';
$lang['mediaextchange']        = 'Dateiendung von .%s nach .%s geändert!';
$lang['reference']             = 'Verwendung von';
$lang['ref_inuse']             = 'Diese Datei kann nicht gelöscht werden, da sie noch von folgenden Seiten benutzt wird:';
$lang['ref_hidden']            = 'Einige Verweise sind auf Seiten, für die Sie keine Leseberechtigung haben.';
$lang['hits']                  = 'Treffer';
$lang['quickhits']             = 'Passende Seitennamen';
$lang['toc']                   = 'Inhaltsverzeichnis';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Ihre Version';
$lang['diff']                  = 'Zeige Unterschiede zu aktueller Version';
$lang['diff2']                 = 'Zeige Unterschiede der ausgewählten Versionen';
$lang['difflink']              = 'Link zu dieser Vergleichsansicht';
$lang['diff_type']             = 'Unterschiede anzeigen:';
$lang['diff_inline']           = 'Inline';
$lang['diff_side']             = 'Nebeneinander';
$lang['diffprevrev']           = 'Vorhergehende Überarbeitung';
$lang['diffnextrev']           = 'Nächste  Überarbeitung';
$lang['difflastrev']           = 'Letzte  Überarbeitung';
$lang['diffbothprevrev']       = 'Beide Seiten der vorigen Revision';
$lang['diffbothnextrev']       = 'Beide Seiten der Revision';
$lang['line']                  = 'Zeile';
$lang['breadcrumb']            = 'Zuletzt angesehen:';
$lang['youarehere']            = 'Sie befinden sich hier:';
$lang['lastmod']               = 'Zuletzt geändert:';
$lang['by']                    = 'von';
$lang['deleted']               = 'gelöscht';
$lang['created']               = 'angelegt';
$lang['restored']              = 'alte Version wiederhergestellt (%s)';
$lang['external_edit']         = 'Externe Bearbeitung';
$lang['summary']               = 'Zusammenfassung';
$lang['noflash']               = 'Das <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> wird benötigt, um diesen Inhalt anzuzeigen.';
$lang['download']              = 'Schnipsel herunterladen';
$lang['tools']                 = 'Werkzeuge';
$lang['user_tools']            = 'Benutzer-Werkzeuge';
$lang['site_tools']            = 'Webseiten-Werkzeuge';
$lang['page_tools']            = 'Seiten-Werkzeuge';
$lang['skip_to_content']       = 'zum Inhalt springen';
$lang['sidebar']               = 'Seitenleiste';
$lang['mail_newpage']          = 'Neue Seite:';
$lang['mail_changed']          = 'Seite geändert:';
$lang['mail_subscribe_list']   = 'Geänderte Seiten im Namensraum:';
$lang['mail_new_user']         = 'Neuer Benutzer:';
$lang['mail_upload']           = 'Datei hochgeladen:';
$lang['changes_type']          = 'Änderungen anzeigen von';
$lang['pages_changes']         = 'Seiten';
$lang['media_changes']         = 'Mediendateien';
$lang['both_changes']          = 'Beides: Seiten- und Mediendateien';
$lang['qb_bold']               = 'Fetter Text';
$lang['qb_italic']             = 'Kursiver Text';
$lang['qb_underl']             = 'Unterstrichener Text';
$lang['qb_code']               = 'Code Text';
$lang['qb_strike']             = 'Durchgestrichener Text';
$lang['qb_h1']                 = 'Level 1 Überschrift';
$lang['qb_h2']                 = 'Level 2 Überschrift';
$lang['qb_h3']                 = 'Level 3 Überschrift';
$lang['qb_h4']                 = 'Level 4 Überschrift';
$lang['qb_h5']                 = 'Level 5 Überschrift';
$lang['qb_h']                  = 'Überschrift';
$lang['qb_hs']                 = 'Wähle die Überschrift';
$lang['qb_hplus']              = 'Obere Überschrift';
$lang['qb_hminus']             = 'Untere Überschrift';
$lang['qb_hequal']             = 'Gleichzeilige Überschrift';
$lang['qb_link']               = 'Interner Link';
$lang['qb_extlink']            = 'Externer Link';
$lang['qb_hr']                 = 'Horizontale Linie';
$lang['qb_ol']                 = 'Nummerierter Listenpunkt';
$lang['qb_ul']                 = 'Listenpunkt';
$lang['qb_media']              = 'Bilder und andere Dateien hinzufügen (öffnet sich in einem neuen Fenster)';
$lang['qb_sig']                = 'Unterschrift einfügen';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Sonderzeichen';
$lang['upperns']               = 'zum übergeordneten Namensraum springen';
$lang['metaedit']              = 'Metadaten bearbeiten';
$lang['metasaveerr']           = 'Die Metadaten konnten nicht gesichert werden';
$lang['metasaveok']            = 'Metadaten gesichert';
$lang['img_title']             = 'Titel:';
$lang['img_caption']           = 'Bildunterschrift:';
$lang['img_date']              = 'Datum:';
$lang['img_fname']             = 'Dateiname:';
$lang['img_fsize']             = 'Größe:';
$lang['img_artist']            = 'FotografIn:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Kamera:';
$lang['img_keywords']          = 'Schlagwörter:';
$lang['img_width']             = 'Breite:';
$lang['img_height']            = 'Höhe:';
$lang['subscr_subscribe_success'] = '%s hat nun Änderungen der Seite %s abonniert';
$lang['subscr_subscribe_error'] = '%s kann die Änderungen der Seite %s nicht abonnieren';
$lang['subscr_subscribe_noaddress'] = 'Weil Ihre E-Mail-Adresse fehlt, können Sie das Thema nicht abonnieren';
$lang['subscr_unsubscribe_success'] = 'Das Abonnement von %s für die Seite %s wurde aufgelöst';
$lang['subscr_unsubscribe_error'] = 'Das Abonnement von %s für die Seite %s konnte nicht aufgelöst werden';
$lang['subscr_already_subscribed'] = '%s hat %s bereits abonniert';
$lang['subscr_not_subscribed'] = '%s hat %s nicht abonniert';
$lang['subscr_m_not_subscribed'] = 'Sie haben die aktuelle Seite und ihre Namensräume nicht abonniert.';
$lang['subscr_m_new_header']   = 'Abonnement hinzufügen';
$lang['subscr_m_current_header'] = 'Aktuelle Abonnements';
$lang['subscr_m_unsubscribe']  = 'Löschen';
$lang['subscr_m_subscribe']    = 'Abonnieren';
$lang['subscr_m_receive']      = 'Benachrichtigung';
$lang['subscr_style_every']    = 'E-Mail bei jeder Bearbeitung';
$lang['subscr_style_digest']   = 'E-Mail-Zusammenfassung der Änderungen jeder Seite (Alle %.2f Tage)';
$lang['subscr_style_list']     = 'Liste der geänderten Seiten (Alle %.2f Tage)';
$lang['authtempfail']          = 'Benutzerüberprüfung momentan nicht möglich. Falls das Problem andauert, wenden Sie sich bitte an den Admin.';
$lang['i_chooselang']          = 'Wählen Sie Ihre Sprache';
$lang['i_installer']           = 'DokuWiki Installation';
$lang['i_wikiname']            = 'Wiki-Name';
$lang['i_enableacl']           = 'Zugangskontrolle (ACL) aktivieren (empfohlen)';
$lang['i_superuser']           = 'Benutzername des Administrators';
$lang['i_problems']            = 'Das Installationsprogramm hat unten aufgeführte Probleme festgestellt, die zunächst behoben werden müssen bevor Sie mit der Installation fortfahren können.';
$lang['i_modified']            = 'Aus Sicherheitsgründen arbeitet dieses Skript nur mit einer neuen bzw. nicht modifizierten DokuWiki Installation. Sie sollten entweder alle Dateien noch einmal frisch installieren oder die <a href="http://dokuwiki.org/install">Dokuwiki-Installationsanleitung</a> konsultieren.';
$lang['i_funcna']              = 'Die PHP-Funktion <code>%s</code> ist nicht verfügbar. Unter Umständen wurde sie von Ihrem Hoster deaktiviert?';
$lang['i_disabled']            = 'Es wurde von Ihrem Provider deaktiviert.';
$lang['i_funcnmail']           = '<b>Hinweis:</b> Die PHP-Funktion "mail()" ist nicht verfügbar. %s Alternativ können Sie das <a href="https://www.dokuwiki.org/plugin:smtp">SMTP-Plugin</a> installieren.';
$lang['i_phpver']              = 'Ihre PHP-Version <code>%s</code> ist niedriger als die benötigte Version <code>%s</code>. Bitte aktualisieren Sie Ihre PHP-Installation.';
$lang['i_mbfuncoverload']      = 'Um DokuWiki zu starten muss mbstring.func_overload in php.ini ausgeschaltet sein.';
$lang['i_urandom']             = 'DokuWiki kann keine kryptografisch sicheren Werte für Cookies generieren. Möglicherweise möchten Sie Ihre "open_basedir"-Einstellungen in der zutreffenden php.ini auf korrekten Zugriff auf <code>/ dev/urandom</ code> überprüfen.';
$lang['i_permfail']            = '<code>%s</code> ist nicht durch DokuWiki beschreibbar. Sie müssen die Berechtigungen dieses Ordners ändern!';
$lang['i_confexists']          = '<code>%s</code> existiert bereits';
$lang['i_writeerr']            = '<code>%s</code> konnte nicht erzeugt werden. Sie sollten die Verzeichnis-/Datei-Rechte überprüfen und die Datei manuell anlegen.';
$lang['i_badhash']             = 'Unbekannte oder modifizierte dokuwiki.php (Hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - unerlaubter oder leerer Wert';
$lang['i_success']             = 'Die Konfiguration wurde erfolgreich abgeschlossen. Sie können jetzt die install.php löschen. Ihr <a href="doku.php?id=wiki:welcome">neues DokuWiki</a> ist jetzt für Sie bereit.';
$lang['i_failure']             = 'Es sind Fehler beim Schreiben der Konfigurationsdateien aufgetreten. Sie müssen diese von Hand beheben, bevor Sie Ihr <a href="doku.php?id=wiki:welcome">neues DokuWiki</a> nutzen können.';
$lang['i_policy']              = 'Anfangseinstellungen der Zugangskontrolle (ACL)';
$lang['i_pol0']                = 'Offenes Wiki (lesen, schreiben und hochladen für alle Benutzer)';
$lang['i_pol1']                = 'Öffentliches Wiki (Lesen für alle, Schreiben und Hochladen nur für registrierte Benutzer)';
$lang['i_pol2']                = 'Geschlossenes Wiki (Lesen, Schreiben und Hochladen nur für registrierte Benutzer)';
$lang['i_allowreg']            = 'Benutzer dürfen sich registrieren';
$lang['i_retry']               = 'Wiederholen';
$lang['i_license']             = 'Bitte wählen Sie die Lizenz, unter die Sie Ihre Inhalte stellen möchten:';
$lang['i_license_none']        = 'Lizensierungsinformation nicht anzeigen';
$lang['i_pop_field']           = 'Bitte helfen Sie mit, DokuWiki zu verbessern:';
$lang['i_pop_label']           = 'Einmal monatlich anonymisierte Nutzungsdaten an das DokuWiki-Entwicklerteam senden';
$lang['recent_global']         = 'Im Moment sehen Sie die Änderungen im Namensraum <b>%s</b>. Sie können auch <a href="%s">die Änderungen im gesamten Wiki sehen</a>.';
$lang['years']                 = 'vor %d Jahren';
$lang['months']                = 'vor %d Monaten';
$lang['weeks']                 = 'vor %d Wochen';
$lang['days']                  = 'vor %d Tagen';
$lang['hours']                 = 'vor %d Stunden';
$lang['minutes']               = 'vor %d Minuten';
$lang['seconds']               = 'vor %d Sekunden';
$lang['wordblock']             = 'Ihre Bearbeitung wurde nicht gespeichert, da sie gesperrten Text enthielt (Spam).';
$lang['media_uploadtab']       = 'Hochladen';
$lang['media_searchtab']       = 'Suchen';
$lang['media_file']            = 'Datei';
$lang['media_viewtab']         = 'Anzeigen';
$lang['media_edittab']         = 'Bearbeiten';
$lang['media_historytab']      = 'Verlauf';
$lang['media_list_thumbs']     = 'Vorschaubilder';
$lang['media_list_rows']       = 'Reihen';
$lang['media_sort_name']       = 'Name';
$lang['media_sort_date']       = 'Datum';
$lang['media_namespaces']      = 'Namensraum wählen';
$lang['media_files']           = 'Dateien in %s';
$lang['media_upload']          = 'In den <strong>%s</strong> Namensraum hochladen.';
$lang['media_search']          = 'Im Namensraum <strong>%s</strong> suchen.';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s in %s';
$lang['media_edit']            = '%s bearbeiten';
$lang['media_history']         = 'Versionsverlauf von %s.';
$lang['media_meta_edited']     = 'Meta-Informationen bearbeitet';
$lang['media_perm_read']       = 'Sie besitzen nicht die notwendigen Berechtigungen um die Datei anzuzeigen.';
$lang['media_perm_upload']     = 'Sie besitzen nicht die notwendigen Berechtigungen, um Dateien hochzuladen.';
$lang['media_update']          = 'Neue Version hochladen';
$lang['media_restore']         = 'Diese Version wiederherstellen';
$lang['media_acl_warning']     = 'Diese Liste ist möglicherweise nicht vollständig. Versteckte und durch ACL gesperrte Seiten werden nicht angezeigt.';
$lang['email_fail']            = 'PHP-Funktion "mail ()" fehlt oder ist deaktiviert. Die folgende E-Mail wurde nicht gesendet:';
$lang['currentns']             = 'Aktueller Namensraum';
$lang['searchresult']          = 'Suchergebnisse';
$lang['plainhtml']             = 'HTML Klartext';
$lang['wikimarkup']            = 'Wiki Markup';
$lang['page_nonexist_rev']     = 'Die Seite exitiert nicht unter %s. Sie wurde aber unter <a href="%s">%s</a>';
$lang['unable_to_parse_date']  = 'Parameter "%s" kann nicht geparsed werden.';
$lang['email_signature_text']  = 'Diese E-Mail wurde erzeugt vom DokuWiki unter
@DOKUWIKIURL@';
